@@ -20,6 +20,14 @@ func cobraRun(ctx context.Context, cmd *Command) func(*cobra.Command, []string)
 		meta := extractMeta(ctx)
 		meta.command = cmd
 
+		// Check if --list-sub-commands flag is set
+		listSubCommandsFlag, err := cobraCmd.PersistentFlags().GetBool("list-sub-commands")
+		if err == nil && listSubCommandsFlag {
+			printAllSubCommands(cobraCmd, 0)
+
+			return nil
+		}
+
 		sentry.AddCommandContext(cmd.GetCommandLine("scw"))
 
 		// If command requires authentication and the client was not directly provided in the bootstrap config, we create a new client and overwrite the existing one
@@ -251,16 +259,22 @@ func handleUnmarshalErrors(cmd *Command, unmarshalErr *args.UnmarshalArgError) e
 		switch e.Err.(type) { //nolint:gocritic
 		case *args.CannotParseBoolError:
 			return &CliError{
-				Err:     errors.New(""),
-				Message: fmt.Sprintf("invalid value for '%s' argument: invalid boolean value", unmarshalErr.ArgName),
-				Hint:    "Possible values: true, false",
+				Err: errors.New(""),
+				Message: fmt.Sprintf(
+					"invalid value for '%s' argument: invalid boolean value",
+					unmarshalErr.ArgName,
+				),
+				Hint: "Possible values: true, false",
 			}
 		case *args.CannotParseDateError:
 			dateErr := e.Err.(*args.CannotParseDateError)
 
 			return &CliError{
-				Err:     fmt.Errorf("date parsing error: %s", dateErr.ArgValue),
-				Message: fmt.Sprintf("could not parse %s as either an absolute time (RFC3339) nor a relative time (+/-)RFC3339", dateErr.ArgValue),
+				Err: fmt.Errorf("date parsing error: %s", dateErr.ArgValue),
+				Message: fmt.Sprintf(
+					"could not parse %s as either an absolute time (RFC3339) nor a relative time (+/-)RFC3339",
+					dateErr.ArgValue,
+				),
 				Details: fmt.Sprintf(`Absolute time error: %s
 Relative time error: %s
 `, dateErr.AbsoluteTimeParseError, dateErr.RelativeTimeParseError),
@@ -312,6 +326,14 @@ func cobraRunHelp(cmd *Command) func(cmd *cobra.Command, args []string) error {
 			return nil
 		}
 
+		// Check if --list-sub-commands flag is set
+		listSubCommandsFlag, err := cobraCmd.PersistentFlags().GetBool("list-sub-commands")
+		if err == nil && listSubCommandsFlag {
+			printAllSubCommands(cobraCmd, 0)
+
+			return nil
+		}
+
 		err = cobraCmd.Help()
 		if err != nil {
 			return err
