@@ -50,8 +50,12 @@ func sdkStdErrorInterceptor(
 	switch sdkError := err.(type) {
 	case *scw.ResourceNotFoundError:
 		return nil, &CliError{
-			Message: fmt.Sprintf("cannot find resource '%v' with ID '%v'", sdkError.Resource, sdkError.ResourceID),
-			Err:     err,
+			Message: fmt.Sprintf(
+				"cannot find resource '%v' with ID '%v'",
+				sdkError.Resource,
+				sdkError.ResourceID,
+			),
+			Err: err,
 		}
 	case *scw.ResponseError:
 		return nil, &CliError{
@@ -86,7 +90,12 @@ func sdkStdErrorInterceptor(
 		invalidArgs := make([]string, len(sdkError.Details))
 		resources := make([]string, len(sdkError.Details))
 		for i, d := range sdkError.Details {
-			invalidArgs[i] = fmt.Sprintf("- %s has reached its quota (%d/%d)", d.Resource, d.Current, d.Quota)
+			invalidArgs[i] = fmt.Sprintf(
+				"- %s has reached its quota (%d/%d)",
+				d.Resource,
+				d.Current,
+				d.Quota,
+			)
 			resources[i] = fmt.Sprintf("'%v'", d.Resource)
 		}
 
@@ -118,9 +127,14 @@ func sdkStdErrorInterceptor(
 		}
 
 		return nil, &CliError{
-			Message: fmt.Sprintf("resource %s with ID %s expired since %s", sdkError.Resource, sdkError.ResourceID, sdkError.ExpiredSince.String()),
-			Err:     err,
-			Hint:    hint,
+			Message: fmt.Sprintf(
+				"resource %s with ID %s expired since %s",
+				sdkError.Resource,
+				sdkError.ResourceID,
+				sdkError.ExpiredSince.String(),
+			),
+			Err:  err,
+			Hint: hint,
 		}
 	}
 
