@@ -223,6 +223,10 @@ type TestConfig struct {
 	EnableAliases bool
 }
 
+func (config *TestConfig) DebugString() string {
+	return config.Cmd
+}
+
 // getTestFilePath returns a valid filename path based on the go test name and suffix. (Take care of non fs friendly char)
 func getTestFilePath(t *testing.T, suffix string) string {
 	t.Helper()
@@ -306,6 +310,25 @@ func createTestClient(
 // because they will be executed without waiting.
 var DefaultRetryInterval *time.Duration
 
+var foldersUsingVCRv4 = []string{
+	"instance",
+	"k8s",
+	"marketplace",
+}
+
+func folderUsesVCRv4(fullFolderPath string) bool {
+	fullPathSplit := strings.Split(fullFolderPath, string(os.PathSeparator))
+
+	folder := fullPathSplit[len(fullPathSplit)-2]
+	for _, migratedFolder := range foldersUsingVCRv4 {
+		if migratedFolder == folder {
+			return true
+		}
+	}
+
+	return false
+}
+
 // Run a CLI integration test. See TestConfig for configuration option
 func Test(config *TestConfig) func(t *testing.T) {
 	return func(t *testing.T) {
@@ -348,7 +371,23 @@ func Test(config *TestConfig) func(t *testing.T) {
 			ctx = interactive.InjectMockResponseToContext(ctx, config.PromptResponseMocks)
 		}
 
-		httpClient, cleanup, err := getHTTPRecoder(t, *UpdateCassettes)
+		folder, err := os.Getwd()
+		if err != nil {
+			t.Fatalf("cannot detect working directory for testing")
+		}
+
+		// Create an HTTP client with recording capabilities
+		var (
+			httpClient *http.Client
+			cleanup    func()
+		)
+
+		if folderUsesVCRv4(folder) {
+			httpClient, cleanup, err = newHTTPRecorder(t, folder, *UpdateCassettes)
+		} else {
+			httpClient, cleanup, err = getHTTPRecoder(t, *UpdateCassettes)
+		}
+
 		require.NoError(t, err)
 		defer cleanup()
 
@@ -641,6 +680,14 @@ func ExecBeforeCmdArgs(args []string) BeforeFunc {
 	}
 }
 
+// ExecBeforeCmdWithResult executes the given command and returns its result.
+func ExecBeforeCmdWithResult(ctx *BeforeFuncCtx, cmd string) any {
+	args := cmdToArgs(ctx.Meta, cmd)
+	ctx.Logger.Debugf("ExecBeforeCmd: args=%s\n", args)
+
+	return ctx.ExecuteCmd(args)
+}
+
 // ExecAfterCmd executes the given before command.
 func ExecAfterCmd(cmd string) AfterFunc {
 	return func(ctx *AfterFuncCtx) error {
