@@ -3,10 +3,10 @@ package e2e_test
 import (
 	"testing"
 
-	"github.com/alecthomas/assert"
 	"github.com/scaleway/scaleway-cli/v2/core"
 	"github.com/scaleway/scaleway-cli/v2/internal/namespaces/test/v1"
 	sdktest "github.com/scaleway/scaleway-sdk-go/api/test/v1"
+	"github.com/stretchr/testify/assert"
 )
 
 // TestSdkStandardErrors tests standard errors
@@ -36,6 +36,7 @@ func TestSdkStandardErrors(t *testing.T) {
 			for range 10 {
 				ctx.ExecuteCmd([]string{"scw", "test", "human", "create"})
 			}
+
 			return nil
 		},
 		Cmd: "scw test human create",
@@ -55,7 +56,8 @@ func TestSdkStandardErrors(t *testing.T) {
 			_, err := api.RunHuman(&sdktest.RunHumanRequest{
 				HumanID: "0194fdc2-fa2f-fcc0-41d3-ff12045b73c8",
 			})
-			assert.Equal(t, nil, err)
+			assert.NoError(t, err)
+
 			return nil
 		},
 		Cmd: "scw test human update human-id=0194fdc2-fa2f-fcc0-41d3-ff12045b73c8 eyes-color=red",
