@@ -2,7 +2,7 @@
 
 package function
 
-import "github.com/scaleway/scaleway-cli/v2/internal/core"
+import "github.com/scaleway/scaleway-cli/v2/core"
 
 func functionDeploy() *core.Command {
 	return nil
