@@ -2,7 +2,9 @@ package mongodb
 
 import (
 	"context"
+	"reflect"
 	"strings"
+	"time"
 
 	"github.com/fatih/color"
 	"github.com/scaleway/scaleway-cli/v2/core"
@@ -11,6 +13,10 @@ import (
 	"github.com/scaleway/scaleway-sdk-go/scw"
 )
 
+const (
+	instanceActionTimeout = 20 * time.Minute
+)
+
 var instanceStatusMarshalSpecs = human.EnumMarshalSpecs{
 	mongodb.InstanceStatusConfiguring: &human.EnumMarshalSpec{
 		Attribute: color.FgBlue,
@@ -53,6 +59,18 @@ func instanceCreateBuilder(c *core.Command) *core.Command {
 	c.ArgSpecs.GetByName("volume.volume-type").Default = core.DefaultValueSetter("sbs_5k")
 	c.ArgSpecs.GetByName("node-type").AutoCompleteFunc = autoCompleteNodeType
 
+	c.WaitFunc = func(ctx context.Context, _, respI any) (any, error) {
+		getResp := respI.(*mongodb.Instance)
+		api := mongodb.NewAPI(core.ExtractClient(ctx))
+
+		return api.WaitForInstance(&mongodb.WaitForInstanceRequest{
+			InstanceID:    getResp.ID,
+			Region:        getResp.Region,
+			Timeout:       scw.TimeDurationPtr(instanceActionTimeout),
+			RetryInterval: core.DefaultRetryInterval,
+		})
+	}
+
 	return c
 }
 
@@ -105,3 +123,47 @@ func autoCompleteNodeType(
 
 	return suggestions
 }
+
+type serverWaitRequest struct {
+	InstanceID string
+	Region     scw.Region
+	Timeout    time.Duration
+}
+
+func instanceWaitCommand() *core.Command {
+	return &core.Command{
+		Short:     `Wait for an instance to reach a stable state`,
+		Long:      `Wait for an instance to reach a stable state. This is similar to using --wait flag.`,
+		Namespace: "mongodb",
+		Resource:  "instance",
+		Verb:      "wait",
+		Groups:    []string{"workflow"},
+		ArgsType:  reflect.TypeOf(serverWaitRequest{}),
+		Run: func(ctx context.Context, argsI any) (i any, err error) {
+			api := mongodb.NewAPI(core.ExtractClient(ctx))
+
+			return api.WaitForInstance(&mongodb.WaitForInstanceRequest{
+				Region:        argsI.(*serverWaitRequest).Region,
+				InstanceID:    argsI.(*serverWaitRequest).InstanceID,
+				Timeout:       scw.TimeDurationPtr(argsI.(*serverWaitRequest).Timeout),
+				RetryInterval: core.DefaultRetryInterval,
+			})
+		},
+		ArgSpecs: core.ArgSpecs{
+			{
+				Name:       "instance-id",
+				Short:      `ID of the instance you want to wait for.`,
+				Required:   true,
+				Positional: true,
+			},
+			core.RegionArgSpec(scw.RegionFrPar, scw.RegionNlAms),
+			core.WaitTimeoutArgSpec(instanceActionTimeout),
+		},
+		Examples: []*core.Example{
+			{
+				Short:    "Wait for an instance to reach a stable state",
+				ArgsJSON: `{"instance_id": "11111111-1111-1111-1111-111111111111"}`,
+			},
+		},
+	}
+}
