@@ -6,6 +6,7 @@ import (
 	"github.com/scaleway/scaleway-cli/v2/core"
 	"github.com/scaleway/scaleway-cli/v2/internal/namespaces/instance/v1"
 	"github.com/scaleway/scaleway-cli/v2/internal/namespaces/lb/v1"
+	mongodb "github.com/scaleway/scaleway-cli/v2/internal/namespaces/mongodb/v1alpha1"
 	"github.com/scaleway/scaleway-cli/v2/internal/namespaces/rdb/v1"
 	"github.com/scaleway/scaleway-cli/v2/internal/namespaces/redis/v1"
 	"github.com/scaleway/scaleway-cli/v2/internal/namespaces/vpc/v2"
@@ -17,6 +18,7 @@ func Test_GetPrivateNetwork(t *testing.T) {
 	cmds.Merge(lb.GetCommands())
 	cmds.Merge(rdb.GetCommands())
 	cmds.Merge(redis.GetCommands())
+	cmds.Merge(mongodb.GetCommands())
 
 	t.Run("Simple", core.Test(&core.TestConfig{
 		Commands: cmds,
@@ -42,6 +44,7 @@ func Test_GetPrivateNetwork(t *testing.T) {
 			createLB(),
 			attachLB(),
 			createRdbInstance("RDB", "PostgreSQL"),
+			createMongoDBInstance("mongoDB"),
 		),
 		Cmd:   "scw vpc private-network get {{ .PN.ID }}",
 		Check: core.TestCheckGolden(),
@@ -52,6 +55,9 @@ func Test_GetPrivateNetwork(t *testing.T) {
 			detachRdbInstance(),
 			waitRdbInstance(),
 			deleteRdbInstance(),
+			detachMongoDBInstance(),
+			waitMongoDBInstance(),
+			deleteMongoDBInstance(),
 			deletePN(),
 		),
 	}))
